@@ -68,9 +68,9 @@ class Structure:
                                                     "",
                                                 ),
                                                 m["name"].replace("_", "\_"),
-                                                # m["detaileddescription"][
-                                                #     "para"
-                                                # ].replace("_", "\_"),
+                                                m["detaileddescription"][
+                                                    "para"
+                                                ].replace("_", "\_"),
                                             ]
                                         )
 
@@ -94,18 +94,18 @@ class Function:
                 if parameterlist["@kind"] == "param":
                     parameteritem = parameterlist["parameteritem"]
                     parameteritem = to_list(parameteritem)
-                    # for p in parameteritem:
-                    #     self.parameters.append(
-                    #         [
-                    #             p["parameternamelist"]["parametername"][
-                    #                 "#text"
-                    #             ].replace("_", "\_"),
-                    #             p["parameternamelist"]["parametername"][
-                    #                 "@direction"
-                    #             ].replace("_", "\_"),
-                    #             p["parameterdescription"]["para"].replace("_", "\_"),
-                    #         ]
-                    #     )
+                    for p in parameteritem:
+                        self.parameters.append(
+                            [
+                                p["parameternamelist"]["parametername"][
+                                    "#text"
+                                ].replace("_", "\_"),
+                                p["parameternamelist"]["parametername"][
+                                    "@direction"
+                                ].replace("_", "\_"),
+                                p["parameterdescription"]["para"].replace("_", "\_"),
+                            ]
+                        )
         self.returns = None
         if m["detaileddescription"]:
             if m["detaileddescription"]["para"]:
